==> ephoto_dam-8.x-3.11.tar.gz: ephoto_dam/js/ephoto_dam.js <==
/**
 * Ephoto Dam Addon for Drupal 9
 *
 * @base   EPHOTO DAM
 * @author EINDEN
 */

(function ($) {
    var EphotoDam = {
        zoomIn: function (img) {
            var overlay = $('#ephoto-dam-overlay').length ? $('#ephoto-dam-overlay'): $('<div id="ephoto-dam-overlay"></div>').appendTo('body');
            var wrap = $('#ephoto-dam-wrap').length ? $('#ephoto-dam-wrap'): $('<div id="ephoto-dam-wrap"><div id="ephoto-dam-close"></div><img></div>').appendTo('body');

            var buffer = new Image();

            buffer.onload = function () {
                var width, height;
                var ratiop = document.documentElement.clientHeight / document.documentElement.clientWidth;
                var ratiof = buffer.height / buffer.width;

                if(ratiop > ratiof) {
                    width = document.documentElement.clientWidth - 100;
                    height = Math.round(width * ratiof);
                }

                else {
                    height = document.documentElement.clientHeight - 100;
                    width = Math.round(height * (1 / ratiof));
                };

                var close = function (event) {
                    event.stopPropagation();
                    event.stopImmediatePropagation();

                    wrap.fadeOut(300);
                    overlay.delay(250).fadeOut(300);
                };

                wrap.children().last().attr('src', img.src);

                wrap.children().first().on('click', close);

                wrap.css(
                    {
                        'width': width,
                        'height': height,
                        'margin-left': -(Math.floor(width / 2) + 8),
                        'margin-top': -(Math.floor(height / 2) + 8)
                    }
                ).delay(250).fadeIn(300);

                overlay.fadeIn(300).on('click', close);
            };

            buffer.src = img.src;
        },
    };

    $('.ephoto-dam-zoom').on(
        'click', function (event) {
            event.stopPropagation();
            event.stopImmediatePropagation();

            EphotoDam.zoomIn(this);
        }
    );

})(jQuery);

==> ephoto_dam-8.x-3.20.tar.gz: ephoto_dam/js/ephoto_dam.js <==
/**
 * Ephoto Dam Addon for Drupal 9
 *
 * @base EPHOTO DAM
 * @author EINDEN
 */

(function ($) {
    var EphotoDam = {
        zoomIn: function (img) {
            var overlay = $('#ephoto-dam-overlay').length ? $('#ephoto-dam-overlay') : $('<div id="ephoto-dam-overlay"></div>').appendTo('body');
            var wrap = $('#ephoto-dam-wrap').length ? $('#ephoto-dam-wrap') : $('<div id="ephoto-dam-wrap"><div id="ephoto-dam-close"></div><img></div>').appendTo('body');

            var buffer = new Image();

            buffer.onload = function () {
                var width, height;
                var ratiop = document.documentElement.clientHeight / document.documentElement.clientWidth;
                var ratiof = buffer.height / buffer.width;

                if(ratiop > ratiof) {
                    width = document.documentElement.clientWidth - 100;
                    height = Math.round(width * ratiof);
                }

                else {
                    height = document.documentElement.clientHeight - 100;
                    width = Math.round(height * (1 / ratiof));
                };

                var close = function (event) {
                    event.stopPropagation();
                    event.stopImmediatePropagation();

                    wrap.fadeOut(300);
                    overlay.delay(250).fadeOut(300);
                };

                wrap.children().last().attr('src', img.src);

                wrap.children().first().on('click', close);

                wrap.css({
                    'width': width,
                    'height': height,
                    'margin-left': -(Math.floor(width / 2) + 8),
                    'margin-top': -(Math.floor(height / 2) + 8)

                }).delay(250).fadeIn(300);

                overlay.fadeIn(300).on('click', close);
            };

            buffer.src = img.src;
        },
    };

    $('.ephoto-dam-zoom').on('click', function (event) {
        event.stopPropagation();
        event.stopImmediatePropagation();

        EphotoDam.zoomIn(this);
    });

})(jQuery);
